Module draft

Module draft 

Draft angle operation for injection molding applications.

Applies a taper to selected faces of a solid relative to a pull direction.

Functions

draft
Apply a draft angle to selected faces of a solid.