Module offset_face

Module offset_face 

Face offset: create a new face offset from an existing face by a given distance along its surface normal.

For planar faces, this is an exact operation (translate along normal). For NURBS faces, the offset is approximated by sampling the surface normal field and refitting via surface interpolation.

Functions

offset_face
Create a new face that is offset from face_id by distance along the outward surface normal.