Module offset_wire

Module offset_wire 

Wire offset: produce a parallel wire at a given distance.

Creates a new wire that is parallel to the input wire, offset by a specified distance.

Enums

JoinType
How to join offset edges at corners.

Functions

offset_wire
Offset a planar wire by a given distance.
offset_wire_with_join
Offset a planar wire by a given distance with a specific join type.