Module query

Module query 

Shape query utilities.

Functions

filter_filletable_edges
Filter edges to only those the blend engine can fillet: manifold edges (shared by exactly two distinct faces) that meet at a real (non-tangent) angle.
filter_planar_edges
Filter edges to only those shared by two planar faces in a solid.