Module shell_op

Module shell_op 

Shell (hollow/offset) operation for creating thin-walled solids.

Offsets faces of a solid inward to create a hollow shell with uniform wall thickness. Optionally removes specified faces to create openings.

Functions

shell
Create a hollow shell from a solid by offsetting faces inward.