Module split

Module split 

Split a solid into two halves along a cutting plane.

Divides a solid into two new solids along the specified cutting plane.

Structs

SplitResult
Result of splitting a solid: two halves.

Functions

split
Split a solid into two halves along a plane.