pub struct SplitResult {
pub positive: SolidId,
pub negative: SolidId,
}Expand description
Result of splitting a solid: two halves.
Fields
positive: SolidIdThe half on the positive side of the cutting plane (same side as normal).
negative: SolidIdThe half on the negative side of the cutting plane.