Module transform

Module transform 

Affine transforms applied to topological shapes.

Functions

transform_face
Apply an affine transform to a face, modifying vertex positions, edge curve geometry, and the face surface in place.
transform_solid
Apply an affine transform to a solid, modifying vertex positions and face surface geometry in place.
transform_wire
Apply an affine transform to a wire, modifying vertex positions and edge curve geometry in place.