pub fn face_polygon(
topo: &Topology,
face_id: FaceId,
) -> Result<Vec<Point3>, OperationsError>Expand description
Get a polygon approximation of a face by sampling curved edges.
Samples circle/ellipse edges into 32 points so faces with a single closed-curve edge (e.g. cylinder caps) get a proper polygon.
Errors
Returns an error if the face or its wire cannot be resolved.