Face offset: create a new face offset from an existing face by a given distance along its surface normal.
For planar faces, this is an exact operation (translate along normal). For NURBS faces, the offset is approximated by sampling the surface normal field and refitting via surface interpolation.
Functions
- offset_
face - Create a new face that is offset from
face_idbydistancealong the outward surface normal.