Wire offset: produce a parallel wire at a given distance.
Creates a new wire that is parallel to the input wire, offset by a specified distance.
Enums
- Join
Type - How to join offset edges at corners.
Functions
- offset_
wire - Offset a planar wire by a given distance.
- offset_
wire_ with_ join - Offset a planar wire by a given distance with a specific join type.