Shape query utilities.
Functions
- filter_
filletable_ edges - Filter edges to only those the blend engine can fillet: manifold edges (shared by exactly two distinct faces) that meet at a real (non-tangent) angle.
- filter_
planar_ edges - Filter edges to only those shared by two planar faces in a solid.