Sectioning (slicing) solids with planes.
Computes the cross-section of a solid at a given cutting plane, producing face(s) representing the intersection.
Structs
- Section
- A cross-section result: one or more planar faces on the cutting plane.
Functions
- section
- Compute the cross-section of a solid with a plane.